@@ -5,7 +5,7 @@ use warnings;
 use DateTime;
 use base qw(Class::Accessor);
 
-our $VERSION = '0.3.1';
+our $VERSION = '0.1';
 
 __PACKAGE__->mk_accessors(qw(
     name_ja
@@ -19,7 +19,6 @@ __PACKAGE__->mk_accessors(qw(
     age
     blood_type
     hometown
-    introduction
     twitter
 ));
 
@@ -40,7 +39,6 @@ sub _initialize {
     $self->{name_ja} = $self->family_name_ja.$self->first_name_ja;
     $self->{name_en} = $self->first_name_en.' '.$self->family_name_en;
     $self->{age}     = $self->_calculate_age;
-    $self->{introduction} = $self->_introduction($info{introduction});
 
     return 1;
 }
@@ -71,12 +69,6 @@ sub _datetime_from_date {
     );
 }
 
-sub _introduction {
-    my ($self, $introduction) = @_;
-    $introduction =~ s/\[(\w+)\]/$self->{$1}/g;
-    return $introduction;
-}
-
 1;
 
 __END__
